#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['flityard']

package_data = \
{'': ['*']}

install_requires = \
['requests']

setup(name='flityard',
      version='0.2.0',
      description='A very simple library.',
      author='Gasper Vozel',
      author_email='karantan@gmail.com',
      url='https://github.com/karantan/flityard',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
     )
